@@ -11,6 +11,11 @@ def GrayScale(t):
 	return Point2HexColor(0,0,t)
 
 def Point2HexColor(a,lfrac,tfrac):
+	"""
+	Return web-safe hex triplets.
+	
+	"""
+
 	[H,S,V] = [math.floor(360*a),lfrac,tfrac]
 
 	RGB = hsvToRGB(H,S,V)
@@ -24,17 +29,36 @@ def Point2HexColor(a,lfrac,tfrac):
 
 def hsvToRGB(h, s, v):
 	"""
-	Convert HSV color space to RGB color space
-	
-	Return (r, g, b)
+	Convert HSV (hue, saturation, value) color space 
+	to RGB (red, green blue) color space.
 	
 	**Parameters**
 	
-		**h** :  hue
+		**h** :  float
+			
+			Hue, a number in [0, 360].
 		
-		**s** :  saturation
+		**s** :  float
+			
+			Saturation, a number in [0, 1].
+		
+		**v** :  float
+			
+			Value, a number in [0, 1].
+		
+	**Returns**
 	
-		**v** :  value
+		**r** :  float
+			
+			Red, a number in [0, 1].
+		
+		**g** :  float
+			
+			Green, a number in [0, 1]. 
+		
+		**b** :  float
+			
+			Blue, a number in [0, 1].
 
 	"""
 	hi = math.floor(h / 60.0) % 6
