@@ -198,10 +198,11 @@ def loadSV(fname, comments='#', delimiter='\t', delimiter_regex=None, linebreak=
 			import re
 			delimiter_regex = re.compile( delimiter_regex )
 		F = map( lambda line: delimiter_regex.sub( delimiter, line ), F )
-	
+
 	if headerlines is None:	
 		if comments != '':		# file header = lines at the top beginning with comments
 			headerlines = 0
+
 			for ind in range(len(F)):			
 				line = F[ind]
 				line = delimiter.join(list(csv.reader([line], delimiter=delimiter))[0])
@@ -211,6 +212,14 @@ def loadSV(fname, comments='#', delimiter='\t', delimiter_regex=None, linebreak=
 					headerlines += 1
 				else:
 					break
+				print 'h=',headerlines
+				
+			if headerlines == 0:
+				comments = ''
+				if namesinheader:
+					headerlines = 1
+				else:
+					headerlines = 0	
 		else:
 			if F[0].startswith(comments + 'metadatadict='):
 				metadatadict = eval(F[0].split(comments + 'metadatadict=')[-1])
