@@ -13,7 +13,7 @@ from tabular import utils as utils
 
 __all__ = ['tabular2html']
 
-def tabular2html(fname, X=None, fin=None, title=None, SERVERNAME=None, SERVER_FROM_CURDIR='../', ROWS_PER_PAGE=1000, **kwargs):
+def tabular2html(fname, X=None, fin=None, title=None, printheader=False, split = True, SERVERNAME=None, SERVER_FROM_CURDIR='../', ROWS_PER_PAGE=1000, **kwargs):
 	"""
 	Creates an html representation of tabular data, either from a 
 	tabarray or an externa file (`including ``.hsv``, ``.csv``, ``.tsv``).
@@ -49,6 +49,15 @@ def tabular2html(fname, X=None, fin=None, title=None, SERVERNAME=None, SERVER_FR
 		
 			Description to be used in the <title> tag of the created 
 			html file. 
+
+		**printheader** : boolean
+		
+			If prinheader = True, will print out a "header" and "footer" (both in the body of the HTML documents) on every page.  The header contains information about the name of the input file and the number of rows, as well what the current page number is (if split between multiple documents) and links to any other pages.    The footer contains the same page number and links.  
+	
+	
+		**split** : boolean
+		
+			If split = False, will not split to multiple html pages, regardless of value of ROWS_PER_PAGE
 		
 		**SERVERNAME** :  string
 		
@@ -61,13 +70,15 @@ def tabular2html(fname, X=None, fin=None, title=None, SERVERNAME=None, SERVER_FR
 			Root path of server relative to the current directory.
 			Assumed to be '../'. 
 		
-		**ROWS_PER_PAGE** :  positive integer
+		**ROWS_PER_PAGE** :  positive integer or 'all'
 		
 			This sets the number of records displayed per .html page 
 			(if the tabular file has more than ROWS_PER_PAGE rows, 
 			it will be split into multiple sections on several .html 
 			pages (default = 1000).
 		
+			If the value is 'all' then the page is not split (e.g. it is as if split = False)
+		
 		**See also:**  the kwargs arguments must be valid keyword arguments for :func:`tabular.tabarray.tabarray.__new__`, the 
 		tabarray constructor, see documentation for descriptions
 	
@@ -76,19 +87,27 @@ def tabular2html(fname, X=None, fin=None, title=None, SERVERNAME=None, SERVER_FR
 	# must write to an html file
 	assert fname.endswith( '.html' ), 'fname must end in .html' 
 	
+	if SERVERNAME == None:
+		SERVERNAME = ''
+	assert isinstance(SERVERNAME,str), '"SERVERNAME" argument must a string'
+	if SERVERNAME != '' and not SERVERNAME.startswith(('http://','https://')):
+		SERVERNAME = 'http://' + SERVERNAME
+	if SERVERNAME != '' and SERVERNAME[-1] != '/':
+		SERVERNAME += '/'		
+			
 	if X is None:
 		if fin is not None:
 			if fin.lstrip('/').endswith('.hsv'):
-				kwargs['HSV'] = fin
+				kwargs['HSVfile'] = fin
 			elif fin.endswith('.tsv') or fin.endswith('.csv'):
-				kwargs['SV'] = fin
+				kwargs['SVfile'] = fin
 			elif fin.endswith(('.npy','.npz')):
 				kwargs['binary'] = fin
 			else:
 				assert False, 'This algorithm is being forced to determine the proper file type for web representation from file\'s path (e.g. by looking at extension) since the type is not given explicitly by use of a keyword argument, but is having problems deducing the intended file type from the path (e.g., because the extension is not one of those this algorithm recognizes)'
 		else:
-			assert any([l in kwargs.keys() and kwargs[l] != None for l in ['SV','binary','HSV']]), 'either a tabarray is given, or file path "fin" is given, or one of "HSV","binary", or "SV" keyword arguments are given'
-			
+			assert any([l in kwargs.keys() and kwargs[l] != None for l in ['SVfile','binary','HSVfile']]), 'either a tabarray is given, or file path "fin" is given, or one of "HSV","binary", or "SV" keyword arguments are given'
+
 		X = tb.tabarray(**kwargs)
 
 
@@ -110,10 +129,13 @@ def tabular2html(fname, X=None, fin=None, title=None, SERVERNAME=None, SERVER_FR
 	Num_Cols = len(names)
 	ColorStyles = CSSColoring(names,coloring)
 	CSSFile = fname[:-5] + '.css'
-	CSSPath = 'http://' + SERVERNAME + '/' + CSSFile[len(SERVER_FROM_CURDIR):]
+	CSSPath = SERVERNAME  + CSSFile[len(SERVER_FROM_CURDIR):]
 	WriteOutCSS(ColorStyles[1],CSSFile)
 	HdrNts = HeaderNotations(names,coloring)
 	
+	if not split or ROWS_PER_PAGE == 'all':
+		ROWS_PER_PAGE = Num_Records + 1
+		
 	numSections = int( Num_Records / ROWS_PER_PAGE ) + 1   #computes the number of sections
 	section2file = lambda sectionNum: fname if sectionNum == 0 else splitext(fname)[0] + str( sectionNum ) + splitext(fname)[1]   #section2file(i) returns the name of the .html file corresponding to section number i
 		
@@ -127,21 +149,21 @@ def tabular2html(fname, X=None, fin=None, title=None, SERVERNAME=None, SERVER_FR
 		fromRow = section * ROWS_PER_PAGE   #beginning record number for this section
 		toRow = min( fromRow + ROWS_PER_PAGE, Num_Records)  #ending record number for this section
 		
-		prefix = 'http://' + SERVERNAME + '/' + DirName(fname[len(SERVER_FROM_CURDIR):]) + '/'	
+		prefix = SERVERNAME + DirName(fname[len(SERVER_FROM_CURDIR):]) + '/'	
 		with open( sectionfname, 'w' ) as f:     #open the output file for the section to fileobject 'f' and do: 
 			#write out file header
 			f.write( '<html><META HTTP-EQUIV="Content-Type" CONTENT="text/html; charset=utf-8" /><head><title>' + title + '</title><link rel="stylesheet" type="text/css" href="' + CSSPath + '"</link></head><body>\n' )   
-			f.write( '<p>Tabular File (page ' + str(section+1) + ' of ' + str( numSections ) + ', rows ' + str(fromRow+1) + ' - ' + str(toRow) + '): ' + title + '</p>\n' )
-			
-			f.write( '<p>page ' )
-			if section > 0: 
-				f.write( ' <a href="' + prefix +basename( section2file( section-1 ) ) + '">prev</a> ' ) 
-			if section < numSections-1:
-				f.write( ' <a href="' + prefix + basename( section2file(  section+1 ) ) + '">next</a> ' ) 
-			for page in range( numSections ):
-				f.write( ( ' <a href="' + prefix + basename( section2file( page ) ) + '">' + str( page+1 ) + '</a>' ) if page != section else ' ' + str( page+1 ) )
-
-			f.write( '</p>' )
+			if printheader:
+				f.write( '<p>Tabular File (page ' + str(section+1) + ' of ' + str( numSections ) + ', rows ' + str(fromRow+1) + ' - ' + str(toRow) + '): ' + title + '</p>\n' )
+				f.write( '<p>page ' )
+				if section > 0: 
+					f.write( ' <a href="' + prefix +basename( section2file( section-1 ) ) + '">prev</a> ' ) 
+				if section < numSections-1:
+					f.write( ' <a href="' + prefix + basename( section2file(  section+1 ) ) + '">next</a> ' ) 
+				for page in range( numSections ):
+					f.write( ( ' <a href="' + prefix + basename( section2file( page ) ) + '">' + str( page+1 ) + '</a>' ) if page != section else ' ' + str( page+1 ) )
+	
+				f.write( '</p>' )
 		
 			#write out table with number of cols
 			f.write( '<table border="1" cellspacing="0" cellpadding="4">\n' )
@@ -177,17 +199,20 @@ def tabular2html(fname, X=None, fin=None, title=None, SERVERNAME=None, SERVER_FR
 			f.write( '</tbody>\n' )
 					
 			f.write( '</table>' )
+			
 			# write out hyperlinks to other sections
-			f.write( '<p>page ' )
-			if section > 0: 
-				f.write( ' <a href="' + prefix +basename( section2file( section-1 ) ) + '">prev</a> ' ) 
-			if section < numSections-1:
-				f.write( ' <a href="' + prefix + basename( section2file(  section+1 ) ) + '">next</a> ' ) 
-			for page in range( numSections ):
-				f.write( ( ' <a href="' + prefix + basename( section2file( page ) ) + '">' + str( page+1 ) + '</a>' ) if page != section else ' ' + str( page+1 ) )
+			if printheader:
+				f.write( '<p>page ' )
+				if section > 0: 
+					f.write( ' <a href="' + prefix +basename( section2file( section-1 ) ) + '">prev</a> ' ) 
+				if section < numSections-1:
+					f.write( ' <a href="' + prefix + basename( section2file(  section+1 ) ) + '">next</a> ' ) 
+				for page in range( numSections ):
+					f.write( ( ' <a href="' + prefix + basename( section2file( page ) ) + '">' + str( page+1 ) + '</a>' ) if page != section else ' ' + str( page+1 ) )
+		
+				f.write( '</p>' )
 			
 			#end file
-			f.write( '</p>' )
 			f.write( '</body></html>\n' )
 		
 
@@ -307,6 +332,9 @@ def WriteOutCSS(ColorStyles,outpath):
 	f.write('body, td{\n')
 	f.write('font-size : 10pt;\n')
 	f.write('}\n')
+	f.write('th{\n')
+	f.write('font-weight : bold;\n')
+	f.write('}\n')
 	
 	for Class in ColorStyles.keys():
 		f.write('td.' + Class  + ',th.' + Class + '{\n')
